@@ -1,6 +1,8 @@
 mod array;
 mod btree_set;
 mod hash_set;
+#[cfg(feature = "hashbrown")]
+mod hashbrown_hash_set;
 mod linked_list;
 mod slice;
 mod vec;
